@@ -38,13 +38,13 @@ public:
     {
         connect(qGuiApp, &QGuiApplication::paletteChanged, this, &StyleSingleton::refresh);
 
-        // Use DBus in order to listen for kdeglobals changes directly, as the
+        // Use DBus in order to listen for settings changes directly, as the
         // QApplication doesn't expose the font variants we're looking for,
         // namely smallFont.
         QDBusConnection::sessionBus().connect(QString(),
-                                              QStringLiteral("/KGlobalSettings"),
-                                              QStringLiteral("org.kde.KGlobalSettings"),
-                                              QStringLiteral("notifyChange"),
+                                              QStringLiteral("/KDEPlatformTheme"),
+                                              QStringLiteral("org.kde.KDEPlatformTheme"),
+                                              QStringLiteral("refreshFonts"),
                                               this,
                                               SLOT(notifyWatchersConfigurationChange()));
 
@@ -175,7 +175,7 @@ public:
     KColorScheme viewScheme;
     QFont smallFont;
 
-    QVector<QPointer<PlasmaDesktopTheme>> watchers;
+    QVector<PlasmaDesktopTheme *> watchers;
 
 private:
     QHash<QPair<Kirigami::PlatformTheme::ColorSet, QPalette::ColorGroup>, Colors> m_cache;
@@ -190,6 +190,7 @@ PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
     auto parentItem = qobject_cast<QQuickItem *>(parent);
     if (parentItem) {
         connect(parentItem, &QQuickItem::enabledChanged, this, &PlasmaDesktopTheme::syncColors);
+        connect(parentItem, &QQuickItem::visibleChanged, this, &PlasmaDesktopTheme::syncColors);
         connect(parentItem, &QQuickItem::windowChanged, this, &PlasmaDesktopTheme::syncWindow);
     }
 
@@ -199,7 +200,9 @@ PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
     setSmallFont((*s_style)->smallFont);
 
     syncWindow();
-    syncColors();
+    if (!m_window) {
+        syncColors();
+    }
 }
 
 PlasmaDesktopTheme::~PlasmaDesktopTheme()
@@ -251,6 +254,9 @@ void PlasmaDesktopTheme::syncColors()
     QPalette::ColorGroup group = (QPalette::ColorGroup)colorGroup();
     auto parentItem = qobject_cast<QQuickItem *>(parent());
     if (parentItem) {
+        if (!parentItem->isVisible()) {
+            return;
+        }
         if (!parentItem->isEnabled()) {
             group = QPalette::Disabled;
             // Why also checking the window is exposed?
